<?php

namespace Litecms\Adds\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Adds\Http\Requests\AddsRequest;
use Litecms\Adds\Interfaces\AddsRepositoryInterface;
use Litecms\Adds\Models\Adds;

/**
 * Resource controller class for adds.
 */
class AddsResourceController extends BaseController
{

    /**
     * Initialize adds resource controller.
     *
     * @param type AddsRepositoryInterface $adds
     *
     * @return null
     */
    public function __construct(AddsRepositoryInterface $adds)
    {
        parent::__construct();
        $this->repository = $adds;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Adds\Repositories\Criteria\AddsResourceCriteria::class);
    }

    /**
     * Display a list of adds.
     *
     * @return Response
     */
    public function index(AddsRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Adds\Repositories\Presenter\AddsPresenter::class)
                ->$function();
        }

        $adds = $this->repository->paginate();

        return $this->response->title(trans('adds::adds.names'))
            ->view('adds::adds.index', true)
            ->data(compact('adds'))
            ->output();
    }

    /**
     * Display adds.
     *
     * @param Request $request
     * @param Model   $adds
     *
     * @return Response
     */
    public function show(AddsRequest $request, Adds $adds)
    {

        if ($adds->exists) {
            $view = 'adds::adds.show';
        } else {
            $view = 'adds::adds.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('adds::adds.name'))
            ->data(compact('adds'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new adds.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(AddsRequest $request)
    {

        $adds = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('adds::adds.name')) 
            ->view('adds::adds.create', true) 
            ->data(compact('adds'))
            ->output();
    }

    /**
     * Create new adds.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(AddsRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $adds                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('adds::adds.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('adds/adds/' . $adds->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/adds/adds'))
                ->redirect();
        }

    }

    /**
     * Show adds for editing.
     *
     * @param Request $request
     * @param Model   $adds
     *
     * @return Response
     */
    public function edit(AddsRequest $request, Adds $adds)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('adds::adds.name'))
            ->view('adds::adds.edit', true)
            ->data(compact('adds'))
            ->output();
    }

    /**
     * Update the adds.
     *
     * @param Request $request
     * @param Model   $adds
     *
     * @return Response
     */
    public function update(AddsRequest $request, Adds $adds)
    {
        try {
            $attributes = $request->all();

            $adds->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('adds::adds.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('adds/adds/' . $adds->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('adds/adds/' . $adds->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the adds.
     *
     * @param Model   $adds
     *
     * @return Response
     */
    public function destroy(AddsRequest $request, Adds $adds)
    {
        try {

            $adds->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('adds::adds.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('adds/adds/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('adds/adds/' . $adds->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple adds.
     *
     * @param Model   $adds
     *
     * @return Response
     */
    public function delete(AddsRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('adds::adds.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('adds/adds'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/adds/adds'))
                ->redirect();
        }

    }

    /**
     * Restore deleted adds.
     *
     * @param Model   $adds
     *
     * @return Response
     */
    public function restore(AddsRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('adds::adds.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/adds/adds'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/adds/adds/'))
                ->redirect();
        }

    }

}
